package it.unibo.cs.labp.progetto2001.solmi;

import java.io.*;
import it.unibo.cs.labp.progetto2001.spec.*;

/**
 * Title:        Progetto Laboratorio di Programmazione 2001-2002
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:      Universit di Bologna
 * @author Riccardo Solmi
 * @version 1.0
 */

public class IfStatement implements Statement {

	/**
	 * @uml property=exp associationEnd={multiplicity={(1 1)}}
	 */
	private final Expression exp;

	/**
	 * @uml property=thenStm associationEnd={multiplicity={(1 1)}}
	 */
	private final Statement thenStm;

	/**
	 * @uml property=elseStm associationEnd={multiplicity={(0 1)}}
	 */
	private final Statement elseStm;

  public IfStatement(Expression exp, Statement thenStm) {
    this.exp = exp;
    this.thenStm = thenStm;
    this.elseStm = null;
  }

  public IfStatement(Expression exp, Statement thenStm, Statement elseStm) {
    this.exp = exp;
    this.thenStm = thenStm;
    this.elseStm = elseStm;
  }

  public void prettyPrint(PrintStream out) {
    out.print("if (");
    exp.prettyPrint(out);
    out.println(") {");
    thenStm.prettyPrint(out);
    if (elseStm == null)
      out.println("}");
    else {
      out.println("} else {");
      elseStm.prettyPrint(out);
      out.println("}");
    }
  }

  public void execute() {
    if (exp.evaluate().booleanValue())
      thenStm.execute();
    else if (elseStm != null)
      elseStm.execute();
  }
}